## 1.3.0 (2023-08-21)
### Features (4 changes)
- [no referrer and open in new tab options for external links](biolds1/sosse@6c701a4782d517c80348642e09f68564f8a9bed3) ([merge request](biolds1/sosse!32))
- [HTML content snapshot](biolds1/sosse@95367eb28a71d197c7533b8935ab0c541c9dfc9f) ([merge request](biolds1/sosse!23))
- [foldable header in screenshots view](biolds1/sosse@fa8247c052099c4242c8d8fe707477b49ef68397) ([merge request](biolds1/sosse!21))
- [Document admin page improvement](biolds1/sosse@ea97cfae49b7e6353d3c61f5aa653d06b5c17109) ([merge request](biolds1/sosse!20))
### Bug fixes (3 changes)
- [update extern links if the target is indexed again afterward](biolds1/sosse@f743e44039d34df1c16958112c7d14cb019b690a) ([merge request](biolds1/sosse!32))
- [fix sameSite cookie option formatting](biolds1/sosse@e4ecfa6e001fd9332795fbb63dbd36459b4a4c4c)
- [force screenshot refresh when they changed](biolds1/sosse@0f04fc7da39e7b33b5cf7ad7e6a5b5fdb7df8117) ([merge request](biolds1/sosse!20))

## 1.2.0 (2023-07-14)
### Features (2 changes)
- [crawling status improvements](biolds1/sosse@848fba81977bf56780430592261bd0847ee52110) ([merge request](biolds1/sosse!18))
- [navigation elements removal](biolds1/sosse@0d9d3582486ed45202359fa5174aadc5bb945d3d) ([merge request](biolds1/sosse!16))
### Bug fixes (1 change)
- [fix screenshots resize](biolds1/sosse@5f6ca3441cd402b5d71ad77598b0e8a17c80dbd6) ([merge request](biolds1/sosse!17))

## 1.1.2 (2023-06-30)
### Bug fixes (1 change)
- [fix database configuration documentation](biolds1/sosse@d10379ffbdfe19bbaef302822110641e9495f75a)

## 1.1.1 (2023-06-29)
### Bug fixes (1 change)
- [misc Bookworm, Docker and Selenium fixes](biolds1/sosse@54fcc7043bfc34a6125fa301d58c08ea02e0b292) ([merge request](biolds1/sosse!12))

## 1.1.0 (2023-06-18)
### Features (3 changes)
- [Debian Bookworm support](biolds1/sosse@b2112e5a0a526e777600499d726002ad62612aac) ([merge request](biolds1/sosse!10))
- [browsable archive on homepage view](biolds1/sosse@f3f2c065f63ada182e0f6154b5586dcae1ea5158) ([merge request](biolds1/sosse!8))
- [automatically follow redirection in cached pages](biolds1/sosse@5d2a40ef0d253a5e47746d25d725794d58216cb2) ([merge request](biolds1/sosse!7))
### Bug fixes (2 changes)
- [fix resolving links when the header has a <base> tag](biolds1/sosse@ff6d4f2d33d6395be87c026c5c9f87c457d5f1a7) ([merge request](biolds1/sosse!6))
- [scroll all elements when taking screenshots](biolds1/sosse@1001d51d41241fb971bde65f5f2fa22e583eff17) ([merge request](biolds1/sosse!5))

## 1.0.1 (2023-05-01)
### Features (1 change)
- [doc improvements](biolds1/sosse@1f2cbcc6f4fc9d537358147aa39e538e1020e9ce)
### Bug fixes (1 change)
- [build the Docker release using pypi packages](biolds1/sosse@40f3d6a7e36784b8a515c3ebda60af67e5ded52e)
